@@ -1,6 +1,6 @@
 #ifndef ABC
-#  include <stdlib.h>
-#  include <stdio.h>
+#  include <stdlib.h> 
+#  include <stdio.h> 
 #  define ABD \
 	xyz
 #define xyz 
@@ -9,7 +9,7 @@
 	foo(y)
 #endif
 
-#include <signal.h>
+#include <signal.h> 
 #  define ABD1 \
 	xyz
 #define xyz1 
@@ -18,6 +18,8 @@
 	foo(y)
 
 __inline__ int inline_func(int i) { return i++; }
+#define FOO_NAME(bar)((BAZ*) fooBAR(bar))->baz
+extern double atofoo (__const char *__fooptr);
 extern int extern_func(int i);
 extern int myarray[56];
 extern int myfunc(int myarrayarg[56]);
